@@ -34,7 +34,8 @@ def main():
     result = result.to_html()
     print("Generating report")
     output = open("/output.html","w")
-    output.write(schema_compare.TEMPLATE.replace("{{body}}",result))
+    result = schema_compare.TEMPLATE.replace("{{body}}",result)
+    output.write(result)
     output.close()
 
 if __name__ == "__main__":
